@@ -325,8 +325,8 @@ find_pcie_controller(unsigned domain, unsigned bus, unsigned dev,
       data = 0;
       if( (pcicap = pci_find_cap(pcidev, PCI_CAP_ID_EXP, PCI_CAP_NORMAL)) ){
         data = pci_read_word(pcidev, pcicap->addr + PCI_EXP_LNKSTA);
-      }else if( (pcicap = pci_find_cap(pcidev, PCI_CAP_ID_MSI, PCI_CAP_NORMAL)) ){
-        // FIXME?
+      //}else if( (pcicap = pci_find_cap(pcidev, PCI_CAP_ID_MSI, PCI_CAP_NORMAL)) ){
+      // FIXME?
       }
       if(data){
         c->pcie.gen = data & PCI_EXP_LNKSTA_SPEED;
@@ -1441,7 +1441,6 @@ watch_dir(int fd, const char *dfp, eventfxn fxn, int *wd, int timeout){
       verbf("Watching %s on fd %d\n", dfp, *wd);
     }
   }
-  r = 0;
   if((dir = opendir(dfp)) == NULL){
     diag("Couldn't open %s (%s)\n", dfp, strerror(errno));
     if(fd >= 0){ inotify_rm_watch(fd, *wd); }
@@ -1501,14 +1500,14 @@ watch_dir(int fd, const char *dfp, eventfxn fxn, int *wd, int timeout){
 
 static void
 version(const char *name){
-  diag("%s version %s\n", basename(name), VERSION);
+  diag("%s version %s\n", name, VERSION);
 }
 
 static void
 usage(const char *name, int disphelp){
   diag("usage: %s [ -h|--help ] [ -v|--verbose ] [ -V|--version ]\n"
     "\t[ -t|--target=path ] [ --notroot ] [ -i|--import ]%s\n",
-    basename(name), disphelp ? " [ --disphelp ]" : "");
+    name, disphelp ? " [ --disphelp ]" : "");
 }
 
 static int
@@ -1618,11 +1617,10 @@ event_posix_thread(void *unsafe){
           assert(events[r].events == EPOLLIN);
           while((s = read(em->ifd, buf, buflen)) > 0){
             const struct inotify_event *in;
-            unsigned idx = 0;
 
-            if(s - idx >= (ptrdiff_t)sizeof(*in)){
-              in = (struct inotify_event *)(buf + idx);
-              idx += sizeof(*in);
+            // FIXME can there only be one event per read buffer?
+            if(s >= (ptrdiff_t)sizeof(*in)){
+              in = (struct inotify_event *)(buf);
 
               if(in->len == 0){
                 diag("Nil-file event on unknown watch desc %d\n", in->wd);
@@ -2104,11 +2102,13 @@ int growlight_init(int argc, char * const *argv, const glightui *ui, int *disphe
   return 0;
 
 err:
-  growlight_stop();
+  growlight_stop(-1);
   return -1;
 }
 
-int growlight_stop(void){
+// if calling this on some error path, pass in your non-zero retcode, so that
+// the closing diagnostic doesn't suggest success when we've already failed.
+int growlight_stop(int retcode){
   int r = 0;
 
   diag("Killing the event thread...\n");
@@ -2132,11 +2132,11 @@ int growlight_stop(void){
       return -1;
     }
   }
-  diag("Returning %d...\n", r);
-  if(r){
-    return -1;
+  if(retcode){
+    r = retcode;
   }
-  return 0;
+  diag("Returning %d...\n", r);
+  return r;
 }
 
 int rescan_controller(controller *c){
